==================================================
 downpour -- OpenStack Tenant Data Migration Tool
==================================================

downpour exports tenant data from an OpenStack cloud to create a set
of Ansible_ playbooks for importing the data into another cloud.

.. note::

  The project is in a very very early prototyping stage.

.. _ansible: https://www.ansible.com

Contents
========

.. toctree::
   :maxdepth: 2

   background
   installation
   usage
   resource_file
   history
   contributing
   glossary
